<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Polish
</name>

<description>
   <am>Polish Language Meta-Package</am>
   <ar>Polish Language Meta-Package</ar>
   <bg>Polish Language Meta-Package</bg>
   <ca>Metapaquet de llengua polonesa</ca>
   <cs>Polish Language Meta-Package</cs>
   <da>Polsk sprog-metapakke</da>
   <de>Polnisches Sprach-Meta-Paket</de>
   <el>Πολωνική γλώσσα</el>
   <en>Polish Language Meta-Package</en>
   <es>Polish Language Meta-Package</es>
   <et>Polish Language Meta-Package</et>
   <eu>Polish Language Meta-Package</eu>
   <fa>Polish Language Meta-Package</fa>
   <fi>Polish Language Meta-Package</fi>
   <fr>Méta-paquet pour langue polonaise</fr>
   <he_IL>Polish Language Meta-Package</he_IL>
   <hi>Polish Language Meta-Package</hi>
   <hr>Polish Language Meta-Package</hr>
   <hu>Polish Language Meta-Package</hu>
   <id>Polish Language Meta-Package</id>
   <is>Polish Language Meta-Package</is>
   <it>Meta-pacchetto della lingua polacca</it>
   <ja_JP>Polish Language Meta-Package</ja_JP>
   <ja>Polish Language Meta-Package</ja>
   <kk>Polish Language Meta-Package</kk>
   <ko>Polish Language Meta-Package</ko>
   <lt>Polish Language Meta-Package</lt>
   <mk>Polish Language Meta-Package</mk>
   <nb>Polish Language Meta-Package</nb>
   <nl>Poolse Taal Meta-Pakket</nl>
   <pl>Polski metapakiet językowy</pl>
   <pt_BR>Polonês Meta-Pacote de Idioma</pt_BR>
   <pt>Polaco Meta-Pacote de Idioma</pt>
   <ro>Polish Language Meta-Package</ro>
   <ru>Polish Language Meta-Package</ru>
   <sk>Polish Language Meta-Package</sk>
   <sl>Polish Language Meta-Package</sl>
   <sq>Polish Language Meta-Package</sq>
   <sr>Polish Language Meta-Package</sr>
   <sv>Polskt Språk-Meta-Paket</sv>
   <tr>Polish Language Meta-Package</tr>
   <uk>Polish Language Meta-Package</uk>
   <zh_CN>Polish Language Meta-Package</zh_CN>
   <zh_TW>Polish Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-pl
manpages-pl
myspell-pl
ipolish
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-pl
manpages-pl
myspell-pl
ipolish
</uninstall_package_names>
</app>
